@@ -1,5 +1,5 @@
 # Treep, copyright 2019 Max Planck Gesellschaft
-# Author : Vincent Berenz 
+# Author : Vincent Berenz
 
 # This file is part of Treep.
 
@@ -22,18 +22,17 @@ import subprocess
 
 def execute(command, shell=True):
     try:
-        out = subprocess.check_output( command,
-                                       stderr=subprocess.STDOUT,
-                                       shell=shell )
+        out = subprocess.check_output(
+            command, stderr=subprocess.STDOUT, shell=shell
+        )
     except Exception as e:
         out = e.output
 
-    try :
+    try:
         # python 3
-        out = out.decode("utf-8") 
-    except :
+        out = out.decode("utf-8")
+    except:
         # python 2.7
         pass
-        
-    return out
 
+    return out
