@@ -1,5 +1,5 @@
 # Treep, copyright 2019 Max Planck Gesellschaft
-# Author : Vincent Berenz 
+# Author : Vincent Berenz
 
 # This file is part of Treep.
 
@@ -19,17 +19,12 @@
 
 import copy
 
+
 class Project(object):
 
-    __slots__ = ["name","parent_projects",
-                 "repositories","users",
-                 "parents"]
-    
-    def  __init__(self,
-                  name,
-                  parent_projects,
-                  repositories,
-                  users=None):
+    __slots__ = ["name", "parent_projects", "repositories", "users", "parents"]
+
+    def __init__(self, name, parent_projects, repositories, users=None):
 
         self.name = name
         self.parent_projects = parent_projects
@@ -39,7 +34,3 @@ class Project(object):
     def get_users(self):
 
         return copy.deepcopy(self._users)
-
-    
-        
-        
