@@ -1,5 +1,5 @@
 # Treep, copyright 2019 Max Planck Gesellschaft
-# Author : Vincent Berenz 
+# Author : Vincent Berenz
 
 # This file is part of Treep.
 
@@ -19,7 +19,6 @@
 
 def read_compilation_file(path):
     imported = {}
-    exec(compile(open(path).read(), path, 'exec'),globals(),imported)
+    with open(path) as f:
+        exec(compile(f.read(), path, "exec"), globals(), imported)
     return imported
-
-            
