@@ -1,5 +1,5 @@
 # Treep, copyright 2019 Max Planck Gesellschaft
-# Author : Vincent Berenz 
+# Author : Vincent Berenz
 
 # This file is part of Treep.
 
@@ -21,25 +21,41 @@ from . import coloring
 
 
 class Repository(object):
-
-    def __init__( self,
-                  name,
-                  origin,
-                  path,
-                  branch="master",
-                  commit=None,
-                  tag=None,
-                  compilation=None) :
+    def __init__(
+        self,
+        name,
+        ssh_origin,
+        https_origin,
+        path,
+        remote_type="ssh",
+        branch="master",
+        commit=None,
+        tag=None,
+        compilation=None,
+    ):
 
         if path is None:
-            path = ''
+            path = ""
 
         self.name = name
-        self.origin = origin
+        self.ssh_origin = ssh_origin
+        self.https_origin = https_origin
+        self.remote_type = remote_type
         self.path = path
         self.branch = branch
         self.commit = commit
         self.tag = tag
         self.compilation = compilation
 
-
+    def get_origin(self, remote_type=None):
+        origin = ""
+        if remote_type == "https":
+            origin = self.https_origin
+        elif remote_type == "ssh":
+            origin = self.ssh_origin
+        else:
+            if self.remote_type == "https":
+                origin = self.https_origin
+            else:
+                origin = self.ssh_origin
+        return origin
