@@ -3,7 +3,7 @@ from .process_calls import execute
 
 def authenticity_of_host_is_established(host):
 
-    command = 'ssh '+str(host)+' -o "BatchMode yes"'
+    command = "ssh " + str(host) + ' -o "BatchMode yes"'
 
     out = execute(command)
 
@@ -16,7 +16,7 @@ def authenticity_of_host_is_established(host):
 def get_host(git_url):
 
     git_url = git_url.strip()
-    
+
     if git_url.startswith("https"):
         return None
 
@@ -26,9 +26,9 @@ def get_host(git_url):
 
     else:
         return None
-        
+
     if ":" in host:
-        index = host.rfind(':')
+        index = host.rfind(":")
         host = host[:index]
 
     host = host.strip()
