@@ -1,5 +1,5 @@
 # Treep, copyright 2019 Max Planck Gesellschaft
-# Author : Vincent Berenz 
+# Author : Vincent Berenz
 
 # This file is part of Treep.
 
@@ -19,42 +19,43 @@
 
 from __future__ import print_function
 
-import git,sys,os,time,multiprocessing
+import git, sys, os, time, multiprocessing
 
 from .status import Status
 
 from .process_calls import execute
 
 
-def clone(url,destination_path,submodules=True):
-    git.Repo.clone_from(url,destination_path)
+def clone(url, destination_path, submodules=True):
+    git.Repo.clone_from(url, destination_path)
+
 
 def clone_submodules(path):
     os.chdir(path)
     nb_cpus = multiprocessing.cpu_count()
     nb_cpus -= 1
-    if nb_cpus <= 0 :
-        nb_cpus=1
+    if nb_cpus <= 0:
+        nb_cpus = 1
     execute("git submodule update --init --recursive")
-    
+
+
 def current_branch(path):
     repo = git.Repo.init(path)
     return str(repo.active_branch)
 
 
 def list_branches(path):
-
     def _extract_branch_name(line):
-        line = line.replace('\\n','')
-        line = line.replace("'","")
+        line = line.replace("\\n", "")
+        line = line.replace("'", "")
         if "->" in line:
-            return _extract_branch_name(line[line.rfind("->") + 2:])
+            return _extract_branch_name(line[line.rfind("->") + 2 :])
         try:
             # assumes remotes/origin/branch_name
             # removing 'remotes'
-            line = line[line.find("/")+1:]
+            line = line[line.find("/") + 1 :]
             # removing 'origin'
-            line = line[line.find("/")+1:]
+            line = line[line.find("/") + 1 :]
         except BaseException:
             pass
         line = line.replace("*", "")
@@ -66,64 +67,71 @@ def list_branches(path):
     lines = out.split("\n")
     branches = [_extract_branch_name(line) for line in lines]
     return branches
-    
+
 
 def status_message(path):
     os.chdir(path)
     message = execute("git status")
     return str(message)
 
-def create_branch(path,branch_name):
+
+def create_branch(path, branch_name):
     os.chdir(path)
-    try :
-        execute("git checkout -b "+str(branch_name))
-    except :
-        raise Exception("failed to create branch "+branch_name)
-        
-def checkout_branch(path,branch_name,create=False):
+    try:
+        execute("git checkout -b " + str(branch_name))
+    except:
+        raise Exception("failed to create branch " + branch_name)
+
+
+def checkout_branch(path, branch_name, create=False):
     branches = list_branches(path)
     if branch_name in branches:
         repo = git.Repo.init(path)
         repo.git.checkout(branch_name)
         return
-    else :
+    else:
         if not create:
             raise Exception("no such branch")
-        else :
-            create_branch(path,branch_name)
+        else:
+            create_branch(path, branch_name)
+
 
 def list_tags(path):
     os.chdir(path)
     tags = execute("git tag")
     return tags
-            
-def checkout_tag(path,tag):
+
+
+def checkout_tag(path, tag):
     tags = list_tags(path)
     if tag in tags:
         repo = git.Repo.init(path)
         repo.git.checkout(tag)
         return
-    else :
+    else:
         raise Exception("no such tag")
 
-def checkout_commit(path,commit):
+
+def checkout_commit(path, commit):
     repo = git.Repo.init(path)
     try:
         repo.git.checkout(commit)
     except Exception as e:
-        raise Exception("failed to checkout commit "+str(commit)+": "+str(e))
-    
+        raise Exception(
+            "failed to checkout commit " + str(commit) + ": " + str(e)
+        )
 
-def push_to_origin(path,branch):
+
+def push_to_origin(path, branch):
     # note: not using gitpython: could not understand
     #       how to get the info if the push was a success or not,
     #       experienced pushed that returned undocumented status
     #       messages
     # below throws an exception in case of failure
     os.chdir(path)
-    execute("git push origin "+branch)
+    execute("git push origin " + branch)
+
 
-    
 def fetch_origin(path):
     repo = git.Repo.init(path)
     origin = repo.remotes.origin
@@ -141,28 +149,29 @@ def add_all(path):
 # note: returns None if invalid origin,
 #       because "git remote show origin"
 #       outputs valid result only for valid URL
-def _get_origin(path,pattern):
+def _get_origin(path, pattern):
     os.chdir(path)
     out = execute("git remote show origin")
     lines = out.split("\n")
     for line in lines:
         if pattern in line and "URL:" in line:
-            return line[line.index("URL:")+4:]
+            return line[line.index("URL:") + 4 :]
 
 
 def get_fetch_origin(path):
-    return _get_origin(path,"Fetch")
+    return _get_origin(path, "Fetch")
 
 
 def get_push_origin(path):
-    return _get_origin(path,"Push")
+    return _get_origin(path, "Push")
 
 
-def set_origin(path,origin):
+def set_origin(path, origin):
     os.chdir(path)
-    out = execute("git remote set-url origin "+origin)
+    out = execute("git remote set-url origin " + origin)
 
-def commit(path,message):
+
+def commit(path, message):
     repo = git.Repo.init(path)
     repo.index.commit(str(message))
 
@@ -172,6 +181,7 @@ def pull(path):
     out = execute("git pull")
     return out
 
+
 def local_modifications(path):
     git_status = status_message(path)
     repo = git.Repo(path=path)
@@ -182,19 +192,19 @@ def local_modifications(path):
     return False
 
 
-def get_url(path, remote='origin'):
-    try :
+def get_url(path, remote="origin"):
+    try:
         repo = git.Repo(path=path)
-    except :
+    except:
         return None
     return repo.remote(name=remote).url
 
-    
+
 def get_status(path):
 
-    try :
+    try:
         repo = git.Repo(path=path)
-    except :
+    except:
         return None
 
     status = Status()
@@ -206,62 +216,68 @@ def get_status(path):
         branch = str(repo.active_branch)
     except Exception as e:
         if "detached" in str(e):
-            branch = ("(detached head)")
-        else :
+            branch = "(detached head)"
+        else:
             raise e
     status.branch = branch
 
     # information about last commit on current branch
-    
-    try :
+
+    try:
         commit_instance = repo.commit()
     except ValueError:
         # this happens for example for a repo with no commits
         commit_instance = None
 
     if commit_instance is not None:
-        status.commit_sha1 = repo.head.object.hexsha 
+        status.commit_sha1 = repo.head.object.hexsha
         status.commit_author = commit_instance.author
         status.commit_message = commit_instance.message
         status.commit_summary = commit_instance.summary
-        status.commit_date = time.strftime("%a, %d %b %Y %H:%M", time.gmtime(commit_instance.authored_date))
-        
+        status.commit_date = time.strftime(
+            "%a, %d %b %Y %H:%M", time.gmtime(commit_instance.authored_date)
+        )
+
     # information about remote 'origin'
-        
-    status.origin = repo.remote(name='origin').url
+
+    status.origin = repo.remote(name="origin").url
 
     # diff with master origin
 
     if local_modifications(path):
         status.local_modifications = True
         try:
-                                       
-            status.nb_modified_files = len(repo.index.diff(None)) # local modif
-            status.nb_modified_files += len(repo.index.diff("HEAD")) # staged files
-            status.nb_modified_files += len(repo.untracked_files) # untracked files 
-        except :
+
+            status.nb_modified_files = len(
+                repo.index.diff(None)
+            )  # local modif
+            status.nb_modified_files += len(
+                repo.index.diff("HEAD")
+            )  # staged files
+            status.nb_modified_files += len(
+                repo.untracked_files
+            )  # untracked files
+        except:
             # happens on empty repositories
             status.nb_modified_files = 0
-    else :
+    else:
         status.local_modifications = False
 
     git_status = status_message(path)
-        
+
     if status.local_modifications:
         status.status_message = git_status
-    else :
+    else:
         status.status_message = None
-        
+
     if "behind" in git_status:
         status.behind_origin = True
-    else :
+    else:
         status.behind_origin = False
 
     if "ahead" in git_status:
         status.ahead_origin = True
-    else :
+    else:
         status.ahead_origin = False
-    
+
     return status
-    
-    
